@@ -11,8 +11,6 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: custom.h,v 1.34 2005/10/16 14:48:02 dfs Exp $ */
-
 /*---------------------------------------------------------------------*/
 /* LAT_DEG, LAT_MIN and LAT_SEC: Latitude of your location             */
 /* LON_DEG, LON_MIN and LON_SEC: Longitude of your location            */
@@ -41,11 +39,11 @@
 /* #define DEFAULT_PAGE {"A4", 595, 842} */
   
 /*---------------------------------------------------------------------*/
-/* DATESEP:  The default date separator.  North American usage is '/'; */
-/* others may prefer '-'.                                              */
+/* DATESEP:  The default date separator.  Standard usage is '-';       */
+/* others may prefer '/'.                                              */
 /*---------------------------------------------------------------------*/
-#define DATESEP '/'
-/* #define DATESEP '-' */
+#define DATESEP '-'
+/* #define DATESEP '/' */
 
 /*---------------------------------------------------------------------*/
 /* TIMESEP:  The default time separator.  North American usage is ':'; */
@@ -89,8 +87,7 @@
 
 /*---------------------------------------------------------------------*/
 /* WANT_U_OPTION: Comment out the next define to permanently disable   */
-/* the -u option.  If you do this, however, remind-all.[c]sh will not  */
-/* work.                                                               */
+/* the -u option.                                                      */
 /*---------------------------------------------------------------------*/
 #define WANT_U_OPTION 1
 
@@ -134,19 +131,16 @@
 #define BASE 1990
 
 /*---------------------------------------------------------------------*/
-/* YR_RANGE: The range of years allowed.  Computers with 16-bit        */
-/*           integers can handle about 89 years worth of reminders; if */
-/*           you use 32-bit integers, you can handle over 5 867 000    */
-/*           years.  Note that YR_RANGE is set to 88 rather than 89    */
-/*           because we can range up to the last day of the 88th year. */
+/* YR_RANGE: The range of years allowed.  With 32-bit signed integers, */
+/* the DATETIME type can store 2^31 minutes or about 4074 years.       */
 /*---------------------------------------------------------------------*/
-#define YR_RANGE 88
+#define YR_RANGE 4000
 
 /*---------------------------------------------------------------------*/
 /* VAR_NAME_LEN: The maximum length of variable names.  Don't make it  */
 /*               any less than 12.                                     */
 /*---------------------------------------------------------------------*/
-#define VAR_NAME_LEN 12
+#define VAR_NAME_LEN 16
 
 /*---------------------------------------------------------------------*/
 /* MAX_PRT_LEN: The maximum number of characters to print when         */
@@ -178,17 +172,17 @@
 /*---------------------------------------------------------------------*/
 /* How many attempts to resolve a weird date spec?                     */
 /*---------------------------------------------------------------------*/
-#define TRIG_ATTEMPTS 25
+#define TRIG_ATTEMPTS 50
 
 /*---------------------------------------------------------------------*/
 /* How many global omits of the form YYYY MM DD do we handle?          */
 /*---------------------------------------------------------------------*/
-#define MAX_FULL_OMITS 75
+#define MAX_FULL_OMITS 250
 
 /*---------------------------------------------------------------------*/
 /* How many global omits of the form MM DD do we handle?               */
 /*---------------------------------------------------------------------*/
-#define MAX_PARTIAL_OMITS 75
+#define MAX_PARTIAL_OMITS 250
 
 /*---------------------------------------------------------------------*/
 /* A newline - some systems need "\n\r"                                */
@@ -207,9 +201,9 @@
 /*---------------------------------------------------------------------*/
 /* TAG_LEN: The maximum length of tags.  Don't change it               */
 /*---------------------------------------------------------------------*/
-#define TAG_LEN 32
+#define TAG_LEN 48
 
-#define PASSTHRU_LEN 24
+#define PASSTHRU_LEN 32
 
 #define PSBEGIN "# rem2ps begin"
 #define PSEND   "# rem2ps end"
