@@ -41,8 +41,8 @@ static int Multiply(void), Divide(void), Mod(void), Add(void),
     UnMinus(void), LogNot(void),
     Compare(int);
 
-static int MakeValue (char *s, Value *v, Var *locals);
-static int ParseLiteralDate (char **s, int *jul, int *tim);
+static int MakeValue (char const *s, Value *v, Var *locals);
+static int ParseLiteralDate (char const **s, int *jul, int *tim);
 
 /* Binary operators - all left-associative */
 
@@ -132,9 +132,9 @@ static void CleanStack(void)
 /*  PeekChar - peek ahead to next char.                        */
 /*                                                             */
 /***************************************************************/
-static char PeekChar(char **s)
+static char PeekChar(char const **s)
 {
-    char *t = *s;
+    char const *t = *s;
     while (*t && isspace(*t)) t++;
     return *t;
 }
@@ -146,7 +146,7 @@ static char PeekChar(char **s)
 /*  Read a token.                                              */
 /*                                                             */
 /***************************************************************/
-static int ParseExprToken(DynamicBuffer *buf, char **in)
+static int ParseExprToken(DynamicBuffer *buf, char const **in)
 {
 
     char c;
@@ -266,7 +266,7 @@ static int ParseExprToken(DynamicBuffer *buf, char **in)
 /*  Put the result into value pointed to by v.                 */
 /*                                                             */
 /***************************************************************/
-int EvalExpr(char **e, Value *v)
+int EvalExpr(char const **e, Value *v)
 {
     int r;
 
@@ -289,7 +289,7 @@ int EvalExpr(char **e, Value *v)
 }
 
 /* Evaluate - do the actual work of evaluation. */
-int Evaluate(char **s, Var *locals)
+int Evaluate(char const **s, Var *locals)
 {
     int OpBase, ValBase;
     int r;
@@ -297,7 +297,7 @@ int Evaluate(char **s, Var *locals)
     int args; /* Number of function arguments */
     Operator op, op2;
     Value va;
-    char *ufname = NULL; /* Stop GCC from complaining about use of uninit var */
+    char const *ufname = NULL; /* Stop GCC from complaining about use of uninit var */
 
     OpBase = OpStackPtr;
     ValBase = ValStackPtr;
@@ -339,7 +339,7 @@ int Evaluate(char **s, Var *locals)
 		if (f) r = CallFunc(f, 0);
 		else {
 		    r = CallUserFunc(ufname, 0);
-		    free(ufname);
+		    free((char *) ufname);
 		}
 		if (r) return r;
 		r = ParseExprToken(&ExprBuf, s); /* Guaranteed to be right paren. */
@@ -349,12 +349,12 @@ int Evaluate(char **s, Var *locals)
 		    args++;
 		    r = Evaluate(s, locals);
 		    if (r) {
-			if (!f) free(ufname);
+			if (!f) free((char *) ufname);
 			return r;
 		    }
 		    if (*DBufValue(&ExprBuf) == ')') break;
 		    else if (*DBufValue(&ExprBuf) != ',') {
-			if (!f) free(ufname);
+			if (!f) free((char *) ufname);
 			Eprint("%s: `%c'", ErrMsg[E_EXPECT_COMMA],
 			       *DBufValue(&ExprBuf));
 			DBufFree(&ExprBuf);
@@ -364,7 +364,7 @@ int Evaluate(char **s, Var *locals)
 		if (f) r = CallFunc(f, args);
 		else {
 		    r = CallUserFunc(ufname, args);
-		    free(ufname);
+		    free((char *) ufname);
 		}
 		DBufFree(&ExprBuf);
 		if (r) return r;
@@ -448,7 +448,7 @@ int Evaluate(char **s, Var *locals)
 /*  a date or the value of a symbol.                           */
 /*                                                             */
 /***************************************************************/
-static int MakeValue(char *s, Value *v, Var *locals)
+static int MakeValue(char const *s, Value *v, Var *locals)
 {
     int len;
     int h, m, r;
@@ -456,7 +456,7 @@ static int MakeValue(char *s, Value *v, Var *locals)
     if (*s == '\"') { /* It's a literal string "*/
 	len = strlen(s)-1;
 	v->type = STR_TYPE;
-	v->v.str = (char *) malloc(len);
+	v->v.str = malloc(len);
 	if (! v->v.str) {
 	    v->type = ERR_TYPE;
 	    return E_NO_MEM;
@@ -533,7 +533,7 @@ static int MakeValue(char *s, Value *v, Var *locals)
 int DoCoerce(char type, Value *v)
 {
     int h, d, m, y, i, k;
-    char *s;
+    char const *s;
 
     /* Do nothing if value is already the right type */
     if (type == v->type) return OK;
@@ -751,7 +751,7 @@ static int Add(void)
 	    return r;
 	}
 	v3.type = STR_TYPE;
-	v3.v.str = (char *) malloc(strlen(v1.v.str) + strlen(v2.v.str) + 1);
+	v3.v.str = malloc(strlen(v1.v.str) + strlen(v2.v.str) + 1);
 	if (!v3.v.str) {
 	    DestroyValue(v1); DestroyValue(v2);
 	    return E_NO_MEM;
@@ -1078,7 +1078,7 @@ static int LogNot(void)
 /*  Find a function.                                           */
 /*                                                             */
 /***************************************************************/
-Operator *FindFunc(char *name, Operator where[], int num)
+Operator *FindFunc(char const *name, Operator where[], int num)
 {
     int top=num-1, bot=0;
     int mid, r;
@@ -1102,7 +1102,7 @@ Operator *FindFunc(char *name, Operator where[], int num)
 void PrintValue (Value *v, FILE *fp)
 {
     int y, m, d;
-    char *s;
+    char const *s;
 
     if (v->type == STR_TYPE) {
 	s=v->v.str;
@@ -1154,7 +1154,7 @@ int CopyValue(Value *dest, const Value *src)
 /*  and tim; update s.                                         */
 /*                                                             */
 /***************************************************************/
-static int ParseLiteralDate(char **s, int *jul, int *tim)
+static int ParseLiteralDate(char const **s, int *jul, int *tim)
 {
     int y, m, d;
     int hour, min;
