@@ -42,20 +42,20 @@
 /* Define the structures needed by the file caching system */
 typedef struct cache {
     struct cache *next;
-    char *text;
+    char const *text;
     int LineNo;
 } CachedLine;
 
 typedef struct cheader {
     struct cheader *next;
-    char *filename;
+    char const *filename;
     CachedLine *cache;
     int ownedByMe;
 } CachedFile;
 
 /* Define the structures needed by the INCLUDE file system */
 typedef struct {
-    char *filename;
+    char const *filename;
     int LineNo;
     unsigned int IfFlags;
     int NumIfs;
@@ -73,7 +73,7 @@ static IncludeStruct IStack[INCLUDE_NEST];
 static int IStackPtr = 0;
 
 static int ReadLineFromFile (void);
-static int CacheFile (const char *fname);
+static int CacheFile (char const *fname);
 static void DestroyCache (CachedFile *cf);
 static int CheckSafety (void);
 
@@ -171,7 +171,7 @@ static int ReadLineFromFile(void)
 /*  ShouldCache is 1, cache the file                           */
 /*                                                             */
 /***************************************************************/
-int OpenFile(const char *fname)
+int OpenFile(char const *fname)
 {
     CachedFile *h = CachedFiles;
     int r;
@@ -230,12 +230,12 @@ int OpenFile(const char *fname)
 /*  Returns an indication of success or failure.               */
 /*                                                             */
 /***************************************************************/
-static int CacheFile(const char *fname)
+static int CacheFile(char const *fname)
 {
     int r;
     CachedFile *cf;
     CachedLine *cl;
-    char *s;
+    char const *s;
 
     cl = NULL;
 /* Create a file header */
@@ -349,7 +349,7 @@ int PopFile(void)
 	if (fp != stdin)
 	    (void) fseek(fp, i->offset, 0);  /* Trust that it works... */
     }
-    free(i->filename);
+    free((char *) i->filename);
     return OK;
 }
 
@@ -387,7 +387,7 @@ int DoInclude(ParsePtr p)
 /*  inclusion.                                                 */
 /*                                                             */
 /***************************************************************/
-int IncludeFile(const char *fname)
+int IncludeFile(char const *fname)
 {
     IncludeStruct *i;
     int r;
@@ -432,7 +432,7 @@ int IncludeFile(const char *fname)
 /* GetAccessDate - get the access date of a file.              */
 /*                                                             */
 /***************************************************************/
-int GetAccessDate(char *file)
+int GetAccessDate(char const *file)
 {
     struct stat statbuf;
     struct tm *t1;
@@ -457,10 +457,10 @@ static void DestroyCache(CachedFile *cf)
 {
     CachedLine *cl, *cnext;
     CachedFile *temp;
-    if (cf->filename) free(cf->filename);
+    if (cf->filename) free((char *) cf->filename);
     cl = cf->cache;
     while (cl) {
-	if (cl->text) free (cl->text);
+	if (cl->text) free ((char *) cl->text);
 	cnext = cl->next;
 	free(cl);
 	cl = cnext;
