@@ -12,6 +12,7 @@
 /*                                                             */
 /***************************************************************/
 
+#include "version.h"
 #include "config.h"
 
 #define L_IN_INIT 1
@@ -28,7 +29,6 @@
 #include "protos.h"
 #include "expr.h"
 #include "err.h"
-#include "version.h"
 #include "globals.h"
 
 /***************************************************************
@@ -79,10 +79,10 @@ while (isdigit(*(s))) {    \
     s++;                   \
 }
 
-static void ChgUser(char *u);
-static void InitializeVar(char *str);
+static void ChgUser(char const *u);
+static void InitializeVar(char const *str);
 
-static char *BadDate = "Illegal date on command line\n";
+static char const *BadDate = "Illegal date on command line\n";
 
 static DynamicBuffer default_filename_buf;
 
@@ -94,9 +94,9 @@ static DynamicBuffer default_filename_buf;
 /*  default filename.  Use $DOTREMINDERS or $HOME/.reminders   */
 /*                                                             */
 /***************************************************************/
-static char *DefaultFilename(void)
+static char const *DefaultFilename(void)
 {
-    char *s;
+    char const *s;
 
     DBufInit(&default_filename_buf);
 
@@ -122,14 +122,14 @@ static char *DefaultFilename(void)
 /*  Initialize the system - called only once at beginning!     */
 /*                                                             */
 /***************************************************************/
-void InitRemind(int argc, char *argv[])
+void InitRemind(int argc, char const *argv[])
 {
-    char *arg;
+    char const *arg;
     int i;
     int y, m, d, rep;
     Token tok;
     int InvokedAsRem = 0;
-    char *s;
+    char const *s;
 
     /* Initialize global dynamic buffers */
     DBufInit(&Banner);
@@ -550,12 +550,15 @@ void Usage(void)
 /*  USER environment variables.                                */
 /*                                                             */
 /***************************************************************/
-static void ChgUser(char *user)
+static void ChgUser(char const *user)
 {
     uid_t myuid;
 
     struct passwd *pwent;
-    static char *home, *shell, *username, *logname;
+    static char *home;
+    static char *shell;
+    static char *username;
+    static char *logname;
 
     myuid = getuid();
 
@@ -616,22 +619,29 @@ static void ChgUser(char *user)
 /*  Initialize and preserve a variable                         */
 /*                                                             */
 /***************************************************************/
-static void InitializeVar(char *str)
+static void InitializeVar(char const *str)
 {
-    char *varname, *expr;
+    char const *expr;
+
+    char varname[VAR_NAME_LEN+1];
 
     Value val;
 
     int r;
 
     /* Scan for an '=' sign */
-    varname = str;
-    while (*str && *str != '=') str++;
+    r = 0;
+    while (*str && *str != '=') {
+	if (r < VAR_NAME_LEN) {
+	    varname[r++] = *str;
+	}
+	str++;
+    }
+    varname[r] = 0;
     if (!*str) {
 	fprintf(ErrFp, ErrMsg[M_I_OPTION], ErrMsg[E_MISS_EQ]);
 	return;
     }
-    *str = 0;
     if (!*varname) {
 	fprintf(ErrFp, ErrMsg[M_I_OPTION], ErrMsg[E_MISS_VAR]);
 	return;
