@@ -14,8 +14,6 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: polish.h,v 1.9 2000/02/18 03:53:51 dfs Exp $ */
-
 /* The very first define in a language support file must be L_LANGNAME: */
 #define L_LANGNAME "Polish"
 
@@ -256,7 +254,7 @@ EXTERN char *ErrMsg[] =
     "Po AT oczekiwany jest czas",
     "S\263owo UNTIL u\277yte dw\363krotnie",
     "Niekompletna specyfikacja daty",
-    "S\263owo SCANFROM u\277yte dw\363krotnie",
+    "S\263owo FROM/SCANFROM u\277yte dw\363krotnie",
     "Zmienna",
     "Warto\266\346",
     "*NIE ZDEFINIOWANE*",
@@ -280,7 +278,8 @@ EXTERN char *ErrMsg[] =
     "Brak przypomnie\361.",
     "%d Przypomnienia zakolejkowane na p\363\274niej.\n",
     "Spodziewana liczba",
-    "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)"
+    "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)",
+    "Can't convert between time zones"
 #else /* ISOLATIN1 */
     "OK",
     "Brakujacy ']'",
@@ -356,7 +355,7 @@ EXTERN char *ErrMsg[] =
     "Po AT oczekiwany jest czas",
     "Slowo UNTIL uzyte dwokrotnie",
     "Niekompletna specyfikacja daty",
-    "Slowo SCANFROM uzyte dwokrotnie",
+    "Slowo FROM/SCANFROM uzyte dwokrotnie",
     "Zmienna",
     "Wartosc",
     "*UNDEFINED*",
@@ -380,7 +379,8 @@ EXTERN char *ErrMsg[] =
     "Brak przypomnien.",
     "%d Przypomnienia zakolejkowane na pozniej.\n",
     "Spodziewana liczba",
-    "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)"
+    "Illegal function in WARN clause (NEEDS TRANSLATION TO POLISH)",
+    "Can't convert between time zones"
 #endif /* ISOLATIN1 */
 };
 #endif /* MK_GLOBALS */
@@ -388,11 +388,7 @@ EXTERN char *ErrMsg[] =
 /* The following is only used in init.c */
 #ifdef L_IN_INIT
 #define L_USAGE_OVERRIDE 1
-#ifdef HAVE_PROTOS
-PUBLIC void Usage(void)
-#else
-void Usage()
-#endif /* HAVE_PROTOS */
+void Usage(void)
 {
     fprintf(ErrFp, "\nREMIND %s (%s version) Copyright 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "Copyright 1999-2000 Roaring Penguin Software Inc.\n");
