@@ -15,8 +15,6 @@
 /*                                                             */
 /***************************************************************/
 
-/* $Id: portbr.h,v 1.8 2000/02/18 03:53:52 dfs Exp $ */
-
 /* The very first define in a language support file must be L_LANGNAME: */
 #define L_LANGNAME "Brazilian Portuguese"
 
@@ -222,7 +220,7 @@ EXTERN char *ErrMsg[] =
     "Esperando hora apos AT",
     "Keyword UNTIL usada duas vezes",
     "Especificacao de data incompleta",
-    "Keyword SCANFROM usada duas vezes",
+    "Keyword FROM/SCANFROM usada duas vezes",
     "Variavel",
     "Valor",
     "*INDEFINIDO*",
@@ -246,18 +244,15 @@ EXTERN char *ErrMsg[] =
     "Sem compromissos.",
     "%d compromisso(s) colocados na fila para mais tarde.\n",
     "Esperando numero",
-    "Funcao ilegal na clausula WARN"
+    "Funcao ilegal na clausula WARN",
+    "Can't convert between time zones"
 };
 #endif /* MK_GLOBALS */
 
 /* The following is only used in init.c */
 #ifdef L_IN_INIT
 #define L_USAGE_OVERRIDE 1
-#ifdef HAVE_PROTOS
-PUBLIC void Usage(void)
-#else
-void Usage()
-#endif /* HAVE_PROTOS */
+void Usage(void)
 {
     fprintf(ErrFp, "\nREMIND %s (versao %s) (C) 1992-1998 David F. Skoll\n", VERSION, L_LANGNAME);
     fprintf(ErrFp, "(C) 1999-2000 Roaring Penguin Software Inc.\n");
