@@ -62,9 +62,9 @@ int main(int argc, char *argv[])
 
 /* Set up global vars */
     ArgC = argc;
-    ArgV = argv;
+    ArgV = (char const **) argv;
 
-    InitRemind(argc, argv);
+    InitRemind(argc, (char const **) argv);
     if (DoCalendar || (DoSimpleCalendar && (!NextMode || PsCal))) {
 	ProduceCalendar();
 	return 0;
@@ -134,7 +134,7 @@ static void DoReminders(void)
 {
     int r;
     Token tok;
-    char *s;
+    char const *s;
     Parser p;
 
     if (!UseStdin) {
@@ -330,7 +330,7 @@ int ParseChar(ParsePtr p, int *err, int peek)
 		    return *(p->epos++);
 		}
 	    }
-	    free(p->etext);  /* End of substituted expression */
+	    free((void *) p->etext);  /* End of substituted expression */
 	    p->etext = NULL;
 	    p->epos = NULL;
 	    p->isnested = 0;
@@ -503,7 +503,7 @@ int EvaluateExpr(ParsePtr p, Value *v)
 /*  Eprint - print an error message.                           */
 /*                                                             */
 /***************************************************************/
-void Eprint(const char *fmt, ...)
+void Eprint(char const *fmt, ...)
 {
     va_list argptr;
 
@@ -536,8 +536,8 @@ void Eprint(const char *fmt, ...)
 /***************************************************************/
 void OutputLine(FILE *fp)
 {
-    register char *s = CurLine;
-    register char c = 0;
+    char const *s = CurLine;
+    char c = 0;
 
     while (*s) {
 	if (*s == '\n') Putc('\\', fp);
@@ -554,7 +554,7 @@ void OutputLine(FILE *fp)
 /*  Create a parser given a string buffer                      */
 /*                                                             */
 /***************************************************************/
-void CreateParser(char *s, ParsePtr p)
+void CreateParser(char const *s, ParsePtr p)
 {
     p->text = s;
     p->pos = s;
@@ -576,7 +576,7 @@ void CreateParser(char *s, ParsePtr p)
 void DestroyParser(ParsePtr p)
 {
     if (p->isnested && p->etext) {
-	free(p->etext);
+	free((void *) p->etext);
 	p->etext = NULL;
 	p->isnested = 0;
     }
@@ -589,10 +589,10 @@ void DestroyParser(ParsePtr p)
 /*  on a per-parser basis.                                     */
 /*                                                             */
 /***************************************************************/
-int PushToken(const char *tok, ParsePtr p)
+int PushToken(char const *tok, ParsePtr p)
 {
     DBufFree(&p->pushedToken);
-    if (DBufPuts(&p->pushedToken, (char *) tok) != OK ||
+    if (DBufPuts(&p->pushedToken, tok) != OK ||
 	DBufPutc(&p->pushedToken, ' ') != OK) {
 	DBufFree(&p->pushedToken);
 	return E_NO_MEM;
@@ -977,7 +977,7 @@ int DoErrMsg(ParsePtr p)
     TimeTrig tt;
     Trigger t;
     int r;
-    char *s;
+    char const *s;
 
     DynamicBuffer buf;
 
@@ -1079,7 +1079,7 @@ int CalcMinsFromUTC(int jul, int tim, int *mins, int *isdst)
 /* A macro safe ONLY if used with arg with no side effects! */
 #define ISBLANK(c) (isspace(c) && (c) != '\n')
 
-void FillParagraph(char *s)
+void FillParagraph(char const *s)
 {
 
     int line = 0;
@@ -1087,7 +1087,7 @@ void FillParagraph(char *s)
     int doublespace = 1;
     int pendspace;
     int len;
-    char *t;
+    char const *t;
 
     int roomleft;
 
