@@ -29,7 +29,7 @@
 typedef struct udf_struct {
     struct udf_struct *next;
     char name[VAR_NAME_LEN+1];
-    char *text;
+    char const *text;
     Var *locals;
     char IsActive;
     int nargs;
@@ -47,7 +47,7 @@ extern Value ValStack[];
 extern int ValStackPtr;
 
 static void DestroyUserFunc (UserFunc *f);
-static void FUnset (char *name);
+static void FUnset (char const *name);
 static void FSet (UserFunc *f);
 static int SetUpLocalVars (UserFunc *f);
 static void DestroyLocalVals (UserFunc *f);
@@ -184,7 +184,7 @@ static void DestroyUserFunc(UserFunc *f)
     }
 
     /* Free the function definition */
-    if (f->text) free(f->text);
+    if (f->text) free( (char *) f->text);
 
     /* Free the data structure itself */
     free(f);
@@ -198,7 +198,7 @@ static void DestroyUserFunc(UserFunc *f)
 /*  it exists.                                                 */
 /*                                                             */
 /***************************************************************/
-static void FUnset(char *name)
+static void FUnset(char const *name)
 {
     UserFunc *cur, *prev;
     int h;
@@ -238,12 +238,12 @@ static void FSet(UserFunc *f)
 /*  Call a user-defined function.                              */
 /*                                                             */
 /***************************************************************/
-int CallUserFunc(char *name, int nargs)
+int CallUserFunc(char const *name, int nargs)
 {
     UserFunc *f;
     int h = HashVal(name) % FUNC_HASH_SIZE;
     int i;
-    char *s;
+    char const *s;
 
     /* Search for the function */
     f = FuncHash[h];
@@ -356,7 +356,7 @@ static void DestroyLocalVals(UserFunc *f)
 /*  it is defined, or -1 if it is not defined.                 */
 /*                                                             */
 /***************************************************************/
-int UserFuncExists(char *fn)
+int UserFuncExists(char const *fn)
 {
     UserFunc *f;
     int h = HashVal(fn) % FUNC_HASH_SIZE;
